/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"

/* individual library stuff */
int nlua_loadPlayer( nlua_env env );
